@@ -5,6 +5,8 @@ converter tool along with its options / parameters
 
 import logging
 import os
+import shutil
+
 import pytest
 import yaml
 import subprocess
@@ -184,8 +186,7 @@ class TestNetscalerConverter:
                        controller_version=setup.get('controller_version_v17'))
 
         dummy_obj = 'Lab-Test-Cert'
-	xlsx_file = '%s/ns-ConversionStatus.xlsx' %setup.get('output_file_path')
-        
+        xlsx_file = '%s/ns-ConversionStatus.xlsx' % setup.get('output_file_path')
         assert check_dummy_cert_status(xlsx_file,
                                        certObj=dummy_obj) == True
 
@@ -320,9 +321,9 @@ class TestNetscalerConverter:
             clean_reboot(file_attribute['controller_ip_17_1_1'], file_attribute['controller_user_17_1_1'],
                          file_attribute['controller_password_17_1_1'], file_attribute['controller_version_v17'],
                          file_attribute['license_file_path'])
-            print "Controller is running properly."
+            print("Controller is running properly.")
         else:
-            print "Controller is not running properly."
+            print("Controller is not running properly.")
 
     @pytest.mark.skip_travis
 
@@ -370,9 +371,9 @@ class TestNetscalerConverter:
                          file_attribute['controller_password_17_1_1'],
                          file_attribute['controller_version_v17'],
                          file_attribute['license_file_path'])
-            print "Controller is running properly."
+            print("Controller is running properly.")
         else:
-            print "Controller is not running properly."
+            print("Controller is not running properly.")
 
     @pytest.mark.skip_travis
 
@@ -416,27 +417,8 @@ class TestNetscalerConverter:
         netscaler_conv(config_file_name=setup.get('config_file_name'),
                        controller_version=setup.get('controller_version_v17'))
 
-
     @pytest.mark.skip_travis
-    def test_reboot_clean_controller_v17_1_1(self):
-        """""
-        Verify Controller v17.1.1 is running and clean reboot avi api.
-        After controller setup completed, upload the AviInternal certificate file.
-        """
-        is_up = verify_controller_is_up(file_attribute['controller_ip_17_1_1'],
-                                        file_attribute['controller_user_17_1_1'],
-                                        file_attribute['controller_password_17_1_1'])
-        if is_up:
-            clean_reboot(file_attribute['controller_ip_17_1_1'], file_attribute['controller_user_17_1_1'],
-                         file_attribute['controller_password_17_1_1'],
-                         file_attribute['controller_version_v17'],
-                         file_attribute['license_file_path'])
-            print("Controller is running properly.")
-        else:
-            print("Controller is not running properly.")
 
-
-    @pytest.mark.skip_travis
     @pytest.mark.TCID1_48_1497_20_0
     def test_create_tenant_cloud_and_upload_controller_17_1_1(self, cleanup):
         """
